# -*- coding: utf-8 -*-
# Generated by Django 1.11.20 on 2019-04-16 08:34
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('djangoldp_project', '0009_auto_20190304_1458'),
    ]

    operations = [
        migrations.CreateModel(
            name='BusinessProvider',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(default='', max_length=255)),
                ('fee', models.PositiveIntegerField(default='0')),
            ],
            options={
                'abstract': False,
                'default_permissions': ('add', 'change', 'delete', 'view', 'control'),
            },
        ),
        migrations.RemoveField(
            model_name='project',
            name='businessProviderFee',
        ),
        migrations.RemoveField(
            model_name='project',
            name='businessProvider',
        ),
        migrations.AddField(
            model_name='project',
            name='businessProvider',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.DO_NOTHING, to='djangoldp_project.BusinessProvider'),
        ),
    ]
