# -*- coding: utf-8 -*-
# Generated by Django 1.11 on 2019-01-23 09:52
from __future__ import unicode_literals

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ('djangoldp_project', '0004_auto_20190121_1544'),
    ]

    operations = [
        migrations.CreateModel(
            name='Member',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=255)),
            ],
        ),
        migrations.RemoveField(
            model_name='job',
            name='project',
        ),
        migrations.RemoveField(
            model_name='job',
            name='user',
        ),
        migrations.AlterField(
            model_name='project',
            name='team',
            field=models.ManyToManyField(blank=True, through='djangoldp_project.Member', to=settings.AUTH_USER_MODEL),
        ),
        migrations.DeleteModel(
            name='Job',
        ),
        migrations.AddField(
            model_name='member',
            name='project',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='members', to='djangoldp_project.Project'),
        ),
        migrations.AddField(
            model_name='member',
            name='user',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL),
        ),
    ]
