# -*- coding: utf-8 -*-
# Generated by Django 1.11 on 2018-12-20 09:39
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):
    dependencies = [
        ('djangoldp_project', '0001_initial'),
    ]

    operations = [

    ]
