# -*- coding: utf-8 -*-
# Generated by Django 1.11 on 2019-01-23 14:51
from __future__ import unicode_literals

from django.db import migrations, models
import django.utils.timezone


class Migration(migrations.Migration):

    dependencies = [
        ('djangoldp_project', '0005_auto_20190123_0952'),
    ]

    operations = [
        migrations.RenameField(
            model_name='customer',
            old_name='name',
            new_name='companyName',
        ),
        migrations.RenameField(
            model_name='customer',
            old_name='contactMail',
            new_name='email',
        ),
        migrations.RenameField(
            model_name='customer',
            old_name='contactFirstName',
            new_name='firstName',
        ),
        migrations.RenameField(
            model_name='customer',
            old_name='contactLastName',
            new_name='lastName',
        ),
        migrations.RenameField(
            model_name='customer',
            old_name='contactPhone',
            new_name='phone',
        ),
        migrations.AddField(
            model_name='customer',
            name='role',
            field=models.CharField(blank=True, max_length=255, null=True),
        ),
        migrations.AddField(
            model_name='project',
            name='creationDate',
            field=models.DateField(auto_now_add=True, default=django.utils.timezone.now),
            preserve_default=False,
        ),
    ]
