# -*- coding: utf-8 -*-
# Generated by Django 1.11 on 2019-03-04 10:18
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('djangoldp_project', '0007_auto_20190123_1459'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='member',
            options={'permissions': (('view_project', 'Read'), ('control_project', 'Control'))},
        ),
        migrations.AlterField(
            model_name='project',
            name='jabberRoom',
            field=models.BooleanField(default=True),
        ),
    ]
